# Generated by Django 2.0 on 2017-12-19 14:26

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Event',
            fields=[
                ('key', models.CharField(max_length=100, primary_key=True, serialize=False, verbose_name='key')),
                ('group', models.CharField(db_index=True, max_length=50, verbose_name='group')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='created at')),
            ],
            options={
                'verbose_name': 'events',
                'ordering': ['-created_at'],
            },
        ),
    ]



import re
import types

from django.db import IntegrityError, transaction
from django.db.models import signals


MODEL_SOURCES = {}
HANDLERS = []


# Good enough for now.
class Event(types.SimpleNamespace):
    pass


def process_events(iterable):
    from spark.models import Event as RealEvent

    for event in iterable:
        try:
            with transaction.atomic():
                RealEvent.objects.create(
                    key=event.key,
                    group=event.group,
                    context=repr(event),
                )
        except IntegrityError:
            pass
        else:
            for group, handler in HANDLERS:
                if re.search(group, event.group):
                    handler(event)


def register_model_event_source(*, sender, source):
    MODEL_SOURCES.setdefault(sender, []).append(source)

    def on_post_save(sender, instance, **kwargs):
        process_events(source(instance))

    signals.post_save.connect(on_post_save, sender=sender, weak=False)


def register_group_handler(*, group, handler):
    HANDLERS.append((group, handler))



# Generated by Django 2.0 on 2017-12-19 14:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('spark', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='event',
            options={'ordering': ['-created_at'], 'verbose_name': 'event', 'verbose_name_plural': 'events'},
        ),
        migrations.AddField(
            model_name='event',
            name='context',
            field=models.TextField(blank=True, verbose_name='context'),
        ),
    ]



from django.contrib import admin

from spark.models import Event


@admin.register(Event)
class EventAdmin(admin.ModelAdmin):
    list_display = (
        'key',
        'group',
        'created_at',
        'context',
    )
    list_filter = (
        'group',
        'created_at',
    )



from django.db import models
from django.utils.translation import ugettext_lazy as _


class Event(models.Model):
    key = models.CharField(
        _('key'),
        max_length=100,
        primary_key=True,
    )
    group = models.CharField(
        _('group'),
        max_length=50,
        db_index=True,
    )
    created_at = models.DateTimeField(
        _('created at'),
        auto_now_add=True,
    )
    context = models.TextField(
        _('context'),
        blank=True,
    )

    class Meta:
        ordering = ['-created_at']
        verbose_name = _('event')
        verbose_name_plural = _('events')

    def __str__(self):
        return self.key
